# This file is part of ROBOTGAME
#
# ROBOTGAME is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# ROBOTGAME is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# ROBOTGAME.  If not, see <http://www.gnu.org/licenses/>.
#
# ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' '
#
#                          boulder.py
#                     --------------------
#       date created : Wed Aug 8 2012
#          copyright : (C) 2012 Sakse Dalum
#      maintained by : Sakse Dalum <don_s@hongabar.org>

"""
A rolling boulder.
"""

import pygame

import worldobject

class Boulder(worldobject.WorldObject):
    def __init__(self, level, x, y, movable=True, rolling=True):
        self.__dict__.update(locals())
        worldobject.WorldObject.__init__(self, level, x, y,
                                         movable=movable, speed=1)

        self.anim = 'boulder_right'
        self.frame = 0
        self.anim_speed = 30

    def update(self, e, t, dt):
        # Update the animation
        self.frame = ((self.frame + self.anim_speed * dt) %
                      len(self.level.imgs[self.anim]))

        if self.direction == (1, 0):
            self.anim = 'boulder_right'
        if self.direction == (0, 1):
            self.anim = 'boulder_down'
        if self.direction == (-1, 0):
            self.anim = 'boulder_left'
        if self.direction == (0, -1):
            self.anim = 'boulder_up'

        self.move(*self.direction)

        worldobject.WorldObject.update(self, e, t, dt)

    def draw(self, window):
        self.img = self.level.imgs[self.anim][int(self.frame)]
        window.blit(self.img, (self.x - 32 - self.level.camera_x,
                               self.y - self.img.get_size()[1] + 24
                               - self.level.camera_y))

